const server = 'http://192.168.20.1'
const timeout = 1500;
async function restoreSession(reducer = null) {

    let token = localStorage.getItem('token');
    let username = localStorage.getItem('username');
    let active = token !== null && username !== null && await checkAuth(token);
    if (active && reducer !== null) {
        reducer({ type: 'start', token, username });
    }
    return (active ? { active: true, token, username } : { active: false });
}
async function storeSession(result, token) {
    result.token = await token;
    result.type = 'start';
    console.log(result)
    if (result.permanent) {
        localStorage.setItem('token', result.token);
        localStorage.setItem('username', result.username);
    }
    return result;
}

async function login(formdata) {
    let formData = new FormData();
    formData.append('username', formdata.username)
    formData.append('password', formdata.password);
    formData.append('action', 'login');
    let result = { username: formdata.username, permanent: formdata.permanent }
    const controller = new AbortController();
    const id = setTimeout(() => controller.abort(), timeout);
    const resp = await fetch(`${server}/api/auth`, { signal: controller.signal, method: 'POST', mode: 'cors', body: formData })
        .then(resp => {
            if (resp.ok) return storeSession(result, resp.text());
            else if (resp.status === 401)
                result.error = 'login_failed';
            else throw new Error(resp.error);
            return result;
        })
        .catch((error) => {
            result.error = 'network_connection';
        })
    return result;
}
async function logout(token) {
    let formData = new FormData()
    formData.append('token', token);
    formData.append('action', 'logout');
    const resp = fetch(`${server}/api/auth`, { method: 'POST', mode: 'cors', body: formData }).then(resp => resp.text());
    localStorage.clear();
    return resp;
}
async function checkAuth(token) {
    let formData = new FormData()
    formData.append('token', token);
    formData.append('action', 'check');
    const resp = await fetch(`${server}/api/auth`, { method: 'POST', mode: 'cors', body: formData }).then(resp => resp.text()).then(text => text === 'valid');
    return await resp;
}
async function fetchdb(token = 'azif7eqCl5') {
    const resp = await fetch(`${server}/api/userdb`, { method: 'GET', mode: 'cors', headers: { Authentification: token } })
        .then(resp => resp.text()).then(text => parsedb(text))
    return resp;

}
function createCsvTable(userdb) {
    let res = '';
    let first = true;
    for (let u of userdb) {
        if (first)
            first = false;

        res += `${!first && '\n'}${u.uid},${u.first_name},${u.last_name},${u.rfid_uid},${u.user_pin},${u.enabled ? '1' : '0'}`;
    }
    return res;
}
async function updateUser(token, user) {
    const resp = await fetch(`${server}/api/user/`, { method: 'POST', body: JSON.stringify(user), mode: 'cors', headers: { Authentification: token } })
        .then(resp => resp.json());
    return resp;
}
async function deleteUser(token, user) {
    const resp = await fetch(`${server}/api/user/${user.uid}`, { method: 'DELETE', body: JSON.stringify(user), mode: 'cors', headers: { Authentification: token } })
        .then(resp => resp.json());
    return resp;
}
async function createUser(token, user) {
    const resp = await fetch(`${server}/api/user/`, { method: 'PUT', body: JSON.stringify(user), mode: 'cors', headers: { Authentification: token } })
        .then(resp => resp.json());
    return resp;
}
function parsedb(raw) {

    let lines = raw.split('\n');
    let users = [];
    lines.map((l, line) => {
        let [uid, first_name, last_name, rfid_uid, user_pin, enabled] = l.split([';']);
        users.push({ line, uid, first_name, last_name, rfid_uid, user_pin, enabled: enabled[0] === '1' });
    });
    return users;
}

async function catchRFID(token) {
    const resp = await fetch(`${server}/api/rfid`, { method: 'GET', mode: 'cors', headers: { Authentification: token } })
        .then(resp => resp.json());
    return resp;
}

async function config(token, payload) {
    let reqdata = new FormData();
    for (let [k, v] of Object.entries(payload))
        if (['number', 'string'].includes(typeof (v)))
            reqdata.append(k, v);
    const abort = new AbortController();
    const aborttimer = setTimeout(() => abort.abort(), timeout);
    return fetch(`${server}/api/config`, { signal: abort.signal, method: 'POST', mode: 'cors', body: reqdata, headers:{Authentification: token} }).
        then(resp => resp.ok ? resp.json() : { error: resp.status });
}
const publicfunctions = { login, logout, checkAuth, parsedb, fetchdb, createCsvTable, updateUser, deleteUser, createUser, restoreSession, catchRFID, config };
export default { ...publicfunctions }
export { login, logout, checkAuth, parsedb, fetchdb, createCsvTable, updateUser, deleteUser, createUser, restoreSession, catchRFID, config }