import { h } from "preact";
import { Router, route } from "preact-router";
import { useEffect, useReducer, useState } from "preact/hooks";
import { Header, Menu } from "./index.js";
import { Home, Users, EditUser, Login, Logout, System } from "../route";
import { AppStateProvider, UserTableProvider, menuReducer, sessionReducer, userTableReducer } from "../store";
import api from "../api/index.js";

const menu_items = [
  { text: "Übersicht", path: "/" },
  { text: "Benutzer anlegen", path: "/newuser" },
  { text: "Benutzer verwalten", path: "/users" },
  { text: "System", path: "/system" },
  { text: "Abmelden", path: "/logout" }
]

function App() {
  // useReducer
  const menu = useReducer(menuReducer, false);
  const session = useReducer(sessionReducer, {});
  const [usertable, userreducer] = useReducer(userTableReducer, []);
  const [lasturl, setlasturl] = useState("/");
  if(!session[0]||(session[0]&&session[0].active===undefined))
    api.restoreSession(session[1]);
  useEffect(()=>{
    if(session[0]&&session[0].active){
      api.fetchdb(session[0].token).then(imported => {
        let action = { type: 'import', imported };
        userreducer(action);
    });
  }},[session]);
  const handleRoute = async e => {
    let active = session[0].active;

    switch (e.url) {
      default:
        if (!active) route('/login', true);
        break;
    }
  };

  return (

    <AppStateProvider value={{ menu, session }} >
      <div id="wrapper">
        <Header title={"Doorlock"} />
        <div class="page">
          <Menu items={menu_items} />
          {!menu[0] &&
            <UserTableProvider value={{ usertable, userreducer }} >
              <Router onChange={handleRoute}>
                <Home path="/" user="me" />
                <Login path="login" />
                <System path="/system" />
                <Logout path="/logout" />
                <Users path="/users/:pageid?" />
                <EditUser path="/edituser/:userid?" />
                <EditUser path="/newuser" />
                <div class="container" default>Error 404</div>
              </Router>
            </UserTableProvider>
          }
        </div>
        <footer>
          <div className="container" style={'text-align: center; align-items: center'}>
            <span>&copy; Jean Jacques Avril 2022 </span>
          </div>

        </footer>
      </div>
    </AppStateProvider>
  );

}

export default App;
