import { h, render } from 'preact'

function TextBox({ id, type = 'text', label, disabled, formdata, formchange, maxlength, overridevalue, onChange, onInput, checkInput, allowdChars, showavailable,hinttext }) {

    if (typeof (onInput) === 'undefined' && typeof (formchange) === 'function') {
        onInput = (e) => formchange(p => {
            if (typeof (checkInput) === 'function' && !checkInput(e.target.value)) {
                return ({ ...p, error: { [e.target.id]: 'input_error' } })
            }
            return ({ ...p, [e.target.id]: e.target.value, error: { [e.target.id]: undefined } })
        });
    }
    const onBlur = (e)=>{
        formchange(p =>({ ...p, error: { [e.target.id]: undefined } }));
    }
    return (<>
        <div className={'textbox'} >
            <input placeholder=" " disabled={disabled} type={type} value={overridevalue ? overridevalue : formdata[id] ? formdata[id] : ''} id={id} onBlur={onBlur} onInput={onInput} onChange={onChange} maxlength={maxlength} name={`form-${id}`} />
            <label for={id}>{label}</label>
            {formdata&&formdata.error&&formdata.error[id]&&hinttext&&<div className='textbox__hint'>{hinttext}</div>}
        </div>
        {showavailable && <span class="textbox__info"> {formdata[id] ? formdata[id].length : 0} von {maxlength} Zeichen verwendet.</span>}
    </>)
}
function CheckBox({ id, disabled, label, formdata, formchange }) {
    let onChange = (e) => formchange({ ...formdata, [e.target.id]: e.target.checked });
    return (<div className={'checkbox'} >
        <input disabled={disabled} type={'checkbox'} checked={formdata[id] ? 'on' : ''} id={id} onChange={onChange} name={`from-${id}`} />
        <label for={id}>{label}</label>
    </div>)
}
function Button({ onClick, children, type }) {
    return (<div className={'button'} onClick={onClick} >
        <button type={type} >{children}</button>
    </div>)
}
export { TextBox, CheckBox, Button }