import { h } from 'preact';
import { useContext, useEffect, useState, useCallback } from 'preact/hooks';
import { route } from 'preact-router';
import AppState, { UserTable } from "../../store";
import api from '../../api'
import { Breadcrumbs } from "../../components";
import { CheckBox, Button, TextBox } from '../../components/controls';
function EditUser({ userid }) {
    let [sessiondata,] = useContext(AppState).session;
    const { usertable, userreducer } = useContext(UserTable);
    const [formdata, formchange] = useState({});
    const [rfidscan, setscan] = useState({active:false, rfidscaninterval:null});
    let rfidscaninterval = null;
    let maxlength_uid = 10;
    let maxlength_name = 25;
    let maxlength_pin = 10;
    let maxlength_rfid = 8;
    useEffect(() => {
        if (rfidscan.rfidscaninterval === null && rfidscan.active) {
            rfidscan.rfidscaninterval = setInterval(() => {
                api.catchRFID(sessiondata.token).then(result => {
                    if (result.rfid_uid) {
                        formchange(old => ({ ...old, rfid_uid: result.rfid_uid }))
                        setscan(p => ({...p,active:false}))
                    }
                }).catch(() => { setscan(p => ({...p,active:false})) });
            }, 1000);
        } else if (rfidscan.rfidscaninterval !== null && !rfidscan.active) {
            clearInterval(rfidscan.rfidscaninterval);
            setscan(p => ({...p,rfidscaninterval:null}));
        }
    }, [rfidscan]);
    useEffect(() => {
        let user = userid !== undefined ? usertable.find(u => u.uid === userid) : undefined;
        if (user !== undefined) {
            formchange(user);
        }
    }, [userid, usertable]);
    function uidCount(state, user) {
        return state.reduce((pre, curr) => pre + curr.uid == user.uid ? 1 : 0, 0);
    }
    const onReset = (e) => {
        e.preventDefault();
        let user = userid !== undefined ? usertable.find(u => u.uid === userid) : undefined;
        formchange(user !== undefined ? user : {});
    }

    const runScan = (e) => {
        e.preventDefault();
        setscan(p => ({...p,active:!p.active}));
    }





    const onSubmit = (e) => {
        e.preventDefault();
        let idcount = uidCount(usertable, formdata);
        console.log(idcount);
        if (formdata.line !== undefined) {
            api.updateUser(sessiondata.token, formdata).then(r => {
                userreducer({ type: 'update', user: r })
            });
            route('/users');
        } else if (idcount === 0) {
            api.createUser(sessiondata.token, formdata).then(r => {
                userreducer({ type: 'create', user: r })
            });
            route('/users');
        }
        else {
            alert(`UID ${formdata.uid} wurde bereits ${idcount} mal benutzt`);
        }
    }
    return (
        <div className='container'>
            <Breadcrumbs items={['Benutzerverwaltung', formdata.line != undefined ? "Benutzer Bearbeiten" : "Neuer Benutzer"]} />
            <div className={'contentbox'} >
                <h2>{formdata.line != undefined ? "Benutzer Bearbeiten" : "Neuer Benutzer"}</h2>
                <form onSubmit={onSubmit}>
                    <h3>Eindeutige Identifikationsnummer</h3>
                    <div className='row'>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={formchange} id="uid" label="Benutzer-ID" maxlength={maxlength_uid} showavailable />
                        </div>
                        <div className='column'>
                            <b>Info</b>
                            <span> Nummer muss einmalig sein</span>
                        </div>
                    </div>

                    <h3>Persönliche Daten</h3>
                    <div className='row'>
                        <div className='column'>
                            <TextBox formdata={formdata} formchange={formchange} id="first_name" label="Vorname" maxlength={maxlength_name} showavailable />
                        </div>
                        <div className='column'>
                            <TextBox formdata={formdata} formchange={formchange} id="last_name" label="NachName" maxlength={maxlength_name} showavailable />
                        </div>
                    </div>
                    <h3>Authentifizierung</h3>
                    <div className='row'>
                        <div className='column'>
                            <TextBox formdata={formdata} formchange={formchange} id="rfid_uid" label="RFID" maxlength={maxlength_rfid} disabled={rfidscan.active} overridevalue={rfidscan.active&&"Scannen..."} showavailable />
                        </div>
                        <div className='column'>
                            <Button onClick={runScan}>{rfidscan.active ? "Abbrechen" : "Scannen"}</Button>
                        </div>

                    </div>
                    <div className='row'>
                        <div className='column'>
                            <TextBox formdata={formdata} formchange={formchange} id="user_pin" label="Pin" maxlength={maxlength_pin} showavailable />
                        </div>
                        <div className='column'>
                            <b>Info</b>
                            <span>Achten Sie darauf, eine PIN <br />nicht mehrfach zu benutzen.</span>
                        </div>
                    </div>
                    <h3>Status</h3>
                    <div className='row'>
                        <div className='column'>
                            <CheckBox formdata={formdata} formchange={formchange} id="enabled" type={'checkbox'} label="Benutzer darf sich anmelden" />
                        </div>

                    </div>
                    <div className='row' style={'justify-content: space-between'}>
                        <div className='column'>
                            <Button onClick={onSubmit} >Speichern</Button>
                        </div>
                        <div className='column'>
                            <Button onClick={onReset} >Zurücksetzen</Button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    )
}
export default EditUser;