import { h } from 'preact';
import { route } from 'preact-router';
import { useContext, useState } from 'preact/hooks';
import AppState from '../../store/AppState';
import { Breadcrumbs, Warnbox } from '../../components';
import { CheckBox, Button, TextBox } from '../../components/controls';
import api from '../../api'
function Login() {
    let [sessiondata, setsession] = useContext(AppState).session;
    const [fromdata, setform] = useState({ username: '', password: '', error: null });
    const navigation = ["Login"];
    if (sessiondata.active)
        route('/', true);
    function onSubmit(e) {
        e.preventDefault();
        api.login(fromdata).then(result => {
            if (result.error !== undefined)
                setform(result);
            else {
                setsession(result);
            }
        })

    }
    return (
        <div class="container">
            <Breadcrumbs items={navigation} />
            <div className={'contentbox'} >
                <h2>Anmeldung</h2>
                <p >Bitte melden Sie sich mit ihren Nutzerdaten an.</p>

                {fromdata.error === 'login_failed' && <Warnbox title='Anmeldefehler'>Ungültige Anmeldedaten.<br />Bitte überprüfen Sie den eingebenen Benutzernamen und das Passwort.</Warnbox>}
                {fromdata.error === 'network_connection' && <Warnbox title='Netwerkfehler'>Die Kommunikation mit dem Gerät ist zurzeit nicht möglich.<br />Bitte überprüfen Sie die Netzwerkverbindung.</Warnbox>}
                <form id="login_form" onSubmit={onSubmit} >
                    <div className='row'>
                        <TextBox maxlength={25} formdata={fromdata} formchange={setform} id="username" label="Benutzername" />
                    </div>
                    <div className='row'>
                        <TextBox maxlength={25} formdata={fromdata} formchange={setform} id="password" label="Passwort" type='password' />

                    </div>
                    <div className='row'>
                        <CheckBox id="permanent" formdata={fromdata} formchange={setform} label="Angemeldet bleiben?" />

                    </div>
                    <Button onClick={onSubmit}>Anmelden</Button>

                </form>
            </div>
        </div>
    );

}

export default Login;