import { h } from 'preact';
import { Breadcrumbs } from "../../components";
import { useContext, useEffect, useState } from 'preact/hooks';
import { CheckBox, Button, TextBox } from '../../components/controls';
import AppState from '../../store/AppState';
import api from '../../api'
const checkIP = (v)=>{
    let parts = v.split('.');
    if(parts.length>4) return false;
    for(let part of parts)
        if(isNaN(part)||part>255||part<0||part.length>3)
            return false;
    return true;
}
function System() {
    let [session,] = useContext(AppState).session;
    let [formdata, setform] = useState({});
    useEffect(() => {
        api.config(session.token, { action: "get" }).then(r => setform(p => ({ ...p, ...r })));
    }, [session])
    return (
        <div className='container'>
            <Breadcrumbs items={['Systemeinstellungen']} />
            <div className={'contentbox'} >
                <h2>System</h2>

                <form>
                    <h3>Geräteeinstellungen</h3>
                    <div className='row'>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={setform} id="mode" label="Modus" checkInput={(v)=>!isNaN(v)&&v>=0&&v<=1}  maxlength={1} showavailable hinttext="Nur Zahlen 0 bis 1" />
                        </div>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={setform} id="fail_timeout" label="Login Timeout" checkInput={(v)=>!isNaN(v)&&v>=0&&v<=255}  maxlength={3} showavailable hinttext="Nur Zahlen 0 bis 255" />
                        </div>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={setform} id="hold_time" label="Haltezeit" checkInput={(v)=>!isNaN(v)&&v>=0&&v<=255} maxlength={3} showavailable hinttext="Nur Zahlen 0 bis 255"/>
                        </div>
                    </div>
                    <h3>WiFi Setup</h3>
                    <div className='row'>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={setform} id="SSID" label="WiFi Name" maxlength={31} showavailable />
                        </div>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={setform} id="PASS" label="WiFi Passwort" maxlength={31} showavailable />
                        </div>
                    </div>
                    <div className='row'>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={setform} id="ip" label="IP Adresse" maxlength={15} showavailable checkInput={checkIP} hinttext="Beispiel: 192.168.20.1" />
                        </div>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={setform} id="subnet" label="Netzmaske" maxlength={15} showavailable checkInput={checkIP} hinttext="Beispiel: 255.255.255.0"/>
                        </div>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={setform} id="gw" label="Gateway" maxlength={15} showavailable checkInput={checkIP} hinttext="Beispiel: 0.0.0.0"/>
                        </div>
                    </div>
                    <div className='row'>
                        <div className='column'>
                            <Button onClick={() => null} >Speichern</Button>
                        </div>
                        <div className='column'>
                            <Button onClick={() => null} >Neustart</Button>
                        </div>
                        <div className='column'>
                            <Button onClick={() => null} >Zurücksetzen</Button>
                        </div>
                    </div>
                </form>
                <form>
                    <h3>Admin User</h3>
                    <div className='row'>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={setform} id="ip" label="Name" maxlength={15} showavailable />
                        </div>
                    </div>
                    <div className='row'>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={setform} id="subnet" label="Passwort" maxlength={15} showavailable />
                        </div>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={setform} id="subnet" label="Passwort wiederholen" maxlength={15} showavailable />
                        </div>
                    </div>
                    <div className='row'>
                        <div className='column'>
                            <Button onClick={() => null} >Speichern</Button>
                        </div>
                        <div className='column'>
                            <Button onClick={() => null} >Zurücksetzen</Button>
                        </div>
                    </div>
                </form>
                <h3>Datenbank Backup</h3>
                <div className='row'>
                    <div className="column">
                        <h4>Backup einspielen</h4>
                        <form>
                            <input type={'file'} />
                            <input type={'submit'} value={'Hochladen'} />
                        </form>
                    </div>
                    <div className="column">
                        <h4>Backup herunterladen</h4>
                        <button>Download</button>
                    </div>
                </div>
            </div>
        </div>)
}
export default System