import { h } from "preact";
import { UserList, Pageselector, Breadcrumbs } from "../../components";
import api from '../../api'
import { route } from 'preact-router';
import { useContext, useEffect, useState, useMemo } from "preact/hooks";
import AppState, { UserTable } from "../../store";
function Users({ pageid }) {
    const { usertable, userreducer } = useContext(UserTable);
    let [sessiondata,] = useContext(AppState).session;
    const [viewstate, setview] = useState({ limit: 100, page: 1, pages: 0, query: '' });
    const matchUser = (user, query, fields = ['uid', 'first_name', 'last_name'], exact = false) => {
        let words = query.toLowerCase().split(' ');
        let matches = 0;

        for (let word of words) {
            let match = false;
            for (let key of fields){
                let cmp = user[key].toLowerCase();
                if (exact ? cmp == word : cmp.includes(word)) {
                    match = true;
                    break;
                }
            }
            if (match) {
                matches += 1;
                if(matches >= words.length) return true;
            }
        }
        return false
    }
    const results = useMemo(() => (viewstate.query !== '') ? usertable.filter(u => matchUser(u, viewstate.query)) : usertable, [viewstate.query, usertable]);




    const setPage = (e) => {
        e.preventDefault();
        console.log(e)
        let page = e.target.text;
        setview(state => ({ ...state, page }));
    }

    useEffect(() => {
        setview((state) => {
            let pages = Math.ceil(results.length / state.limit)
            if (state.page >= pages) return ({ ...state, pages, page: pages })
            return ({ ...state, pages })
        })
    }, [results.length, viewstate.limit])
    useEffect(() => {
        if (pageid && !isNaN(pageid))
            setview((state) => ({ ...state, page: pageid }))
    }, [pageid])

    const deleteUser = (user) => {
        api.deleteUser(sessiondata.token, user).then(r => {
            let action = {
                type: 'delete',
                user, r
            }
            userreducer(action)
        })
    }
    const calculateView = () => {
        let start = viewstate.limit * (viewstate.page - 1);
        let end = viewstate.limit * (viewstate.page);
        return { start, end }
    }
    const editUser = (user) => {
        route(`/edituser/${user.uid}`);
    }
    const setLimit = (e) => {
        setview(state => ({ ...state, limit: e.target.value }));
        console.log(e.target.value);
        console.log(viewstate);
    }
    const navigation = ["Benutzerverwaltung",'Übersicht'];
    //
    return (
        <div class="container">
            <Breadcrumbs items={navigation} />
            <div className={'contentbox'} >
                <div>Suche: <input type={'text'} onInput={(e) => setview(state => ({ ...state, query: e.target.value }))} value={viewstate.query} />
                    <button>Hinzufügen</button>
                    Limit: <select onChange={setLimit} value={viewstate.limit}><optgroup label={'Anzahl'}><option>10</option><option>25</option><option>50</option><option>100</option><option>200</option></optgroup><option>Alle</option></select></div>
            </div>
            <UserList {...calculateView()} userlist={results} deleteUser={deleteUser} editUser={editUser} />
            <Pageselector start={1} end={viewstate.pages} current={viewstate.page} setPage={setPage} />


        </div>
    );

}

export default Users;